@@ -52,7 +52,7 @@ public abstract class CtClass {
     /**
      * The version number of this release.
      */
-    public static final String version = "3.10.0.GA";
+    public static final String version = "3.11.0.GA";
 
     /**
      * Prints the version number and the copyright notice.
@@ -410,7 +410,7 @@ public abstract class CtClass {
      *
      * <p>This method may return <code>null</code>.
      */
-    public Collection getRefClasses() {
+    public synchronized Collection getRefClasses() {
         ClassFile cf = getClassFile2();
         if (cf != null) {
             ClassMap cm = new ClassMap() {
@@ -474,6 +474,32 @@ public abstract class CtClass {
         return 0;
     }
 
+    /**
+     * Returns true if the class has the specified annotation class.
+     *
+     * @param clz the annotation class.
+     * @return <code>true</code> if the annotation is found, otherwise <code>false</code>.
+     * @since 3.11
+     */
+    public boolean hasAnnotation(Class clz) {
+        return false;
+    }
+
+    /**
+     * Returns the annotation if the class has the specified annotation class.
+     * For example, if an annotation <code>@Author</code> is associated
+     * with this class, an <code>Author</code> object is returned.
+     * The member values can be obtained by calling methods on
+     * the <code>Author</code> object.
+     *
+     * @param clz the annotation class.
+     * @return the annotation if found, otherwise <code>null</code>.
+     * @since 3.11
+     */
+    public Object getAnnotation(Class clz) throws ClassNotFoundException {
+        return null;
+    }
+
     /**
      * Returns the annotations associated with this class.
      * For example, if an annotation <code>@Author</code> is associated
